@@ -1,15 +1,13 @@
 package MooseX::ClassAttribute::Meta::Role::Attribute;
-{
-  $MooseX::ClassAttribute::Meta::Role::Attribute::VERSION = '0.27';
-}
 
 use strict;
 use warnings;
 
-use List::MoreUtils qw( uniq );
+our $VERSION = '0.28';
 
 use namespace::autoclean;
 use Moose;
+use List::Util 1.45 'uniq';
 
 extends 'Moose::Meta::Role::Attribute';
 
@@ -32,13 +30,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MooseX::ClassAttribute::Meta::Role::Attribute - An attribute metaclass for class attributes in roles
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =head1 DESCRIPTION
 
@@ -49,13 +49,18 @@ attribute declaration in roles.
 
 See L<MooseX::ClassAttribute> for details.
 
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-ClassAttribute>
+(or L<bug-moosex-classattribute@rt.cpan.org|mailto:bug-moosex-classattribute@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is Copyright (c) 2013 by Dave Rolsky.
+This software is Copyright (c) 2016 by Dave Rolsky.
 
 This is free software, licensed under:
 
