@@ -1,11 +1,10 @@
 package MooseX::ClassAttribute::Trait::Attribute;
-BEGIN {
-  $MooseX::ClassAttribute::Trait::Attribute::VERSION = '0.25';
-}
 
 use strict;
 use warnings;
 
+our $VERSION = '0.28';
+
 use namespace::autoclean;
 use Moose::Role;
 
@@ -45,7 +44,10 @@ sub _initialize {
     my $metaclass = shift;
 
     if ( $self->has_default() ) {
-        $self->set_value( undef, $self->default() );
+        $self->set_value(
+            undef,
+            $self->default( $self->associated_class() )
+        );
     }
     elsif ( $self->has_builder() ) {
         $self->set_value( undef, $self->_call_builder( $metaclass->name() ) );
@@ -58,8 +60,8 @@ around default => sub {
 
     my $default = $self->$orig();
 
-    if ( $self->is_default_a_coderef() ) {
-        return $default->( $self->associated_class() );
+    if ( $self->is_default_a_coderef() && @_ ) {
+        return $default->(@_);
     }
 
     return $default;
@@ -136,8 +138,10 @@ if ( $Moose::VERSION < 1.99 ) {
         my $code
             = $meta->_inline_set_class_slot_value( $self->slots(), $value )
             . ";";
-        $code
-            .= $meta->_inline_weaken_class_slot_value( $self->slots(), $value )
+        $code .= $meta->_inline_weaken_class_slot_value(
+            $self->slots(),
+            $value
+            )
             . "    if ref $value;"
             if $self->is_weak_ref();
 
@@ -216,17 +220,19 @@ else {
 
 # ABSTRACT: A trait for class attributes
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MooseX::ClassAttribute::Trait::Attribute - A trait for class attributes
 
 =head1 VERSION
 
-version 0.25
+version 0.28
 
 =head1 DESCRIPTION
 
@@ -242,20 +248,21 @@ is change the behavior of a number of existing methods.
 
 See L<MooseX::ClassAttribute> for details.
 
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-ClassAttribute>
+(or L<bug-moosex-classattribute@rt.cpan.org|mailto:bug-moosex-classattribute@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2016 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
