@@ -1,11 +1,10 @@
 package MooseX::ClassAttribute::Trait::Mixin::HasClassAttributes;
-BEGIN {
-  $MooseX::ClassAttribute::Trait::Mixin::HasClassAttributes::VERSION = '0.26';
-}
 
 use strict;
 use warnings;
 
+our $VERSION = '0.28';
+
 use namespace::autoclean;
 use Moose::Role;
 
@@ -79,17 +78,19 @@ sub remove_class_attribute {
 
 # ABSTRACT: A mixin trait for things which have class attributes
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MooseX::ClassAttribute::Trait::Mixin::HasClassAttributes - A mixin trait for things which have class attributes
 
 =head1 VERSION
 
-version 0.26
+version 0.28
 
 =head1 DESCRIPTION
 
@@ -103,20 +104,21 @@ L<MooseX::ClassAttribute::Trait::Role> for API details.
 
 See L<MooseX::ClassAttribute> for details.
 
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-ClassAttribute>
+(or L<bug-moosex-classattribute@rt.cpan.org|mailto:bug-moosex-classattribute@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is Copyright (c) 2011 by Dave Rolsky.
+This software is Copyright (c) 2016 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
