@@ -1,11 +1,10 @@
 package MooseX::ClassAttribute::Trait::Role;
-{
-  $MooseX::ClassAttribute::Trait::Role::VERSION = '0.27';
-}
 
 use strict;
 use warnings;
 
+our $VERSION = '0.28';
+
 use MooseX::ClassAttribute::Meta::Role::Attribute;
 use Scalar::Util qw( blessed );
 
@@ -46,13 +45,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MooseX::ClassAttribute::Trait::Role - A trait for roles with class attributes
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =head1 SYNOPSIS
 
@@ -95,13 +96,18 @@ If the named class attribute exists, it is removed from the role.
 
 See L<MooseX::ClassAttribute> for details.
 
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-ClassAttribute>
+(or L<bug-moosex-classattribute@rt.cpan.org|mailto:bug-moosex-classattribute@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
-This software is Copyright (c) 2013 by Dave Rolsky.
+This software is Copyright (c) 2016 by Dave Rolsky.
 
 This is free software, licensed under:
 
